CREATE TABLE `actions` (
  `action` varchar(100) NOT NULL DEFAULT '',
  `file` varchar(100) NOT NULL DEFAULT '',
  `title` varchar(100) NOT NULL DEFAULT '',
  `right` int(1) NOT NULL DEFAULT '0',
  `box` varchar(500) DEFAULT NULL,
  `sub` varchar(25) NOT NULL DEFAULT 'main',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=151 DEFAULT CHARSET=utf8;
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','','0','tables exploit','main','147');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','tables exploit','AddFulltext','62');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','tables exploit','AnalyzeTable','63');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','tables exploit','AddPrimaryKey','64');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','65');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables exploit','ChangeAutoInCrementValue','66');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCol','tables.pl','ChangeCol','5','tables exploit','ChangeCol','67');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','68');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCharset','tables.pl','ChangeCharset','5','tables exploit','ChangeCharset','69');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables exploit','ChangeAutoInCrementValue','70');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','tables exploit','ChooseDataBase','71');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropTable','tables.pl','DropTable','5','tables exploit','DropTable','72');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables exploit','DeleteEntry','73');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropCol','tables.pl','DropCol','5','tables exploit','DropCol','74');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpTable','tables.pl','DumpTable','5','tables exploit','ShowDumpTable','75');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ExecSql','tables.pl','ExecSql','5','tables exploit','ExecSql','76');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditTable','tables.pl','SQL','5','tables exploit','EditTable','77');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditEntry','tables.pl','EditEntry','5','tables exploit','EditEntry','78');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables exploit','NewEntry','79');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewTable','tables.pl','NewTable','5','tables exploit','NewTable','80');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateDatabase','tables.pl','CreateDatabase','5','tables exploit','CreateDatabase','81');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('OptimizeTable','tables.pl','OptimizeTable','5','tables exploit','OptimizeTable','82');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RepairTable','tables.pl','RepairTable','5','tables exploit','RepairTable','84');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEditTable','tables.pl','SaveEditTable','5','tables exploit','SaveEditTable','85');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SQL','tables.pl','SQL','5','tables exploit','SQL','86');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables exploit','ShowNewTable','87');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables exploit','SaveEntry','88');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables exploit','DropFulltext','89');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTables','tables.pl','ShowTables','5','tables exploit','ShowTables','90');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','tables exploit','ShowTableDetails','91');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTable','tables.pl','ShowTable','5','tables exploit','ShowTable','92');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('TruncateTable','tables.pl','TruncateTable','5','tables exploit','TruncateTable','93');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables exploit','ShowProcesslist','94');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables exploit','DropFulltext','95');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddIndex','tables.pl','DropFulltext','5','tables exploit','AddIndex','96');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropIndex','tables.pl','DropFulltext','5','tables exploit','DropIndex','97');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddUnique','tables.pl','DropFulltext','5','tables exploit','AddUnique','98');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','tables exploit','ShowNewEntry','99');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables exploit','SaveEntry','100');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables exploit','NewEntry','101');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables exploit','DeleteEntry','102');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleAction','tables.pl','MultipleAction','5','tables exploit','MultipleAction','104');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','tables exploit','ShowDumpDatabase','105');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables exploit','ShowNewTable','106');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewTable','tables.pl','SaveNewTable','5','tables exploit','SaveNewTable','107');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditAction','tables.pl','EditAction','5','tables exploit','EditAction','111');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showProfile','tables.pl','showProfile','5','tables exploit','showProfile','148');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','tables exploit','MultipleDbAction','118');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RenameTable','tables.pl','RenameTable','5','tables exploit','RenameTable','119');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','tables exploit','SaveNewColumn','120');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewDatabase','tables.pl','NewDatabase','5','tables exploit','NewDatabase','121');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','tables exploit','ShowEditIndex','122');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','tables exploit','SaveNewIndex','123');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables exploit','ChangeEngine','124');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeEngine','5','tables exploit','ChangeAutoInCrementValue','125');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowRights','tables.pl','ShowRights','5','tables exploit','ShowRights','127');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveRights','tables.pl','SaveRights','5','tables exploit','SaveRights','128');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowUsers','tables.pl','ShowUsers','5','tables exploit','ShowUsers','129');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateUser','tables.pl','CreateUser','5','tables exploit','CreateUser','130');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteUser','tables.pl','DeleteUser','5','tables exploit','DeleteUser','131');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropDatabase','tables.pl','DropDatabase','5','tables exploit','DropDatabase','132');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','tables exploit','ShowDatabases','133');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables exploit','ShowProcesslist','134');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables exploit','ShowVariables','135');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('translate','translate.pl','translate','5','tables exploit','main','141');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','processlist','5','tables exploit','ShowProcesslist','143');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables exploit','ShowVariables','144');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchDatabase','tables.pl','searchDatabase','5','tables exploit','searchDatabase','145');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('saveProfile','tables.pl','Profile','5','tables exploit','saveProfile','149');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchHelpTopic','tables.pl','Help Topic','5','tables exploit','searchHelpTopic','150');

CREATE TABLE `box` (
  `file` varchar(100) NOT NULL,
  `right` int(1) NOT NULL DEFAULT '0',
  `name` varchar(100) NOT NULL,
  `outId` varchar(100) NOT NULL DEFAULT 'content',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;
INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('tables.pl','5','database','menuBar','10');
INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('exploit.pl','0','exploit','content','11');

CREATE TABLE `exploit` (
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `referer` text NOT NULL,
  `remote_addr` text NOT NULL,
  `query_string` text NOT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `count` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `id` (`id`),
  FULLTEXT KEY `remote_addr` (`remote_addr`)
) ENGINE=MyISAM AUTO_INCREMENT=31 DEFAULT CHARSET=utf8;
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 17:45:07','http://localhost/?/cgi-bin/mysql.pl?action=logout','127.0.0.1','','1','4');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 03:04:28','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=02e9278a94e4f1ad04cf64d25bf3d9b6&captcha=r71&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=02e9278a94e4f1ad04cf64d25bf3d9b6;captcha=r71;submit=save','22','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:42:41','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=4ac2a6b63018dd5f403396062ec78cc7&captcha=fxm&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=4ac2a6b63018dd5f403396062ec78cc7;captcha=fxm;submit=save','3','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 22:02:47','http://localhost/?cgi-bin/mysql.pl?action=showDatabases','127.0.0.1','action=showDatabases','4','23');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:43:38','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=1656e9258cb5af8f619c23c46fa292d2&captcha=hj3&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=1656e9258cb5af8f619c23c46fa292d2;captcha=hj3;submit=save','5','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:43:58','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=a40cf64504dcdd28df465cfc62d04063&captcha=7jb&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=a40cf64504dcdd28df465cfc62d04063;captcha=7jb;submit=save','6','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:44:10','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=af722a11bb6935200d134f8403c4cb27&captcha=gfb&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=af722a11bb6935200d134f8403c4cb27;captcha=gfb;submit=save','7','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:46:27','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=ab62607c854ee15b7778ec0827ed1bd5&captcha=ej6&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=ab62607c854ee15b7778ec0827ed1bd5;captcha=ej6;submit=save','8','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 18:53:38','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=e2683476d2c1b6c9f4e99609ac6748c6&captcha=7ew&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=e2683476d2c1b6c9f4e99609ac6748c6;captcha=7ew;submit=save','9','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 19:01:22','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=51da9dd55d318e05f3c83dbc0eea6388&captcha=i3d&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=51da9dd55d318e05f3c83dbc0eea6388;captcha=i3d;submit=save','10','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 19:01:32','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=a2f1ddf660ccf5c4e7a75a50250ffea3&captcha=pmp&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=a2f1ddf660ccf5c4e7a75a50250ffea3;captcha=pmp;submit=save','11','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 17:31:18','http://localhost/?cgi-bin/mysql.pl?action=ShowTables','127.0.0.1','action=ShowTables','12','4');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 19:37:47','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=34da8fdc815dc88c5498cd0e6ebcc356&captcha=55I&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=34da8fdc815dc88c5498cd0e6ebcc356;captcha=55I;submit=save','13','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 22:31:03','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=1f564695e21cb7bb3beebc8ea3a15b56&captcha=hxp&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=1f564695e21cb7bb3beebc8ea3a15b56;captcha=hxp;submit=save','14','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 23:16:39','http://localhost/?/cgi-bin/mysql.pl?action=EditTable&table=actions','127.0.0.1','action=EditTable;amp=;table=actions','15','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-07 23:16:55','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpasstestpass&md5=68a0d9bf72e49950ea089e83f873430f&captcha=ad5&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpasstestpass;md5=68a0d9bf72e49950ea089e83f873430f;captcha=ad5;submit=save','16','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 09:03:11','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=testpass&md5=f27f973bf9951eedcc9985ff9e0bcb6f&captcha=eqk&submit=save&','127.0.0.1','user=admin;action=login;pass=testpass;md5=f27f973bf9951eedcc9985ff9e0bcb6f;captcha=eqk;submit=save','17','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 09:03:21','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=6d3adaab6ed768ba6c14f40bb04ef8f3&captcha=7Io&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=6d3adaab6ed768ba6c14f40bb04ef8f3;captcha=7Io;submit=save','18','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 11:23:27','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=2becd79f047cbcc16897546fd4625849&captcha=e2v&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=2becd79f047cbcc16897546fd4625849;captcha=e2v;submit=save','19','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 11:23:37','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=e0ea34315d6c03df0a44709b2d162733&captcha=is3&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=e0ea34315d6c03df0a44709b2d162733;captcha=is3;submit=save','20','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-08 14:28:36','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=49d8d3ab8d7f26fa1334754769459024&captcha=dsy&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=49d8d3ab8d7f26fa1334754769459024;captcha=dsy;submit=save','21','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 04:46:42','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpass&md5=1e8193e45969453378cd1d6c1e3ccb88&captcha=fao&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpass;md5=1e8193e45969453378cd1d6c1e3ccb88;captcha=fao;submit=save','23','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 04:47:15','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=318e5060750aaec244ebdcb279d62a9c&captcha=4c5&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=318e5060750aaec244ebdcb279d62a9c;captcha=4c5;submit=save','24','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 04:54:09','http://localhost/?/cgi-bin/mysql.pl?action=ShowTable&table=actions&ajax=true','127.0.0.1','action=ShowTable;table=actions;ajax=true','25','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 06:11:52','http://localhost/?/cgi-bin/mysql.pl?action=EditTable&table=box','127.0.0.1','action=EditTable;amp=;table=box','26','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 19:37:56','http://localhost/?/cgi-bin/mysql.pl?action=searchHelpTopic&topic=help_topic','127.0.0.1','action=searchHelpTopic;topic=help_topic','27','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 19:46:30','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=6d89700735ba409796f157524d080c63&captcha=c5p&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=6d89700735ba409796f157524d080c63;captcha=c5p;submit=save','28','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 19:46:39','http://localhost/?../cgi-bin/mysql.pl?user=admin&action=login&pass=oldpassoldpass&md5=527b2b4e430b967a31f55eaa8a5b5364&captcha=8pf&submit=save&','127.0.0.1','user=admin;action=login;pass=oldpassoldpass;md5=527b2b4e430b967a31f55eaa8a5b5364;captcha=8pf;submit=save','29','1');
INSERT INTO `exploit` (`date`,`referer`,`remote_addr`,`query_string`,`id`,`count`) values('2015-04-09 22:02:25','http://localhost/?/cgi-bin/mysql.pl?action=ShowTable&table=box&desc=0','127.0.0.1','action=ShowTable;table=box;desc=0','30','2');

CREATE TABLE `querys` (
  `title` varchar(100) NOT NULL DEFAULT '',
  `description` text NOT NULL,
  `sql` text NOT NULL,
  `return` varchar(100) NOT NULL DEFAULT 'fetch_array',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `reserved_words` (
  `reserved_word` varchar(50) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=224 DEFAULT CHARSET=latin1;
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ACCESSIBLE','1');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ALTER','2');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('AS','3');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BEFORE','4');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BINARY','5');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BY','6');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CASE','7');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHARACTER','8');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('COLUMN','9');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONTINUE','10');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CROSS','11');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_TIMESTAMP','12');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DATABASE','13');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_MICROSECOND','14');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DEC','15');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DEFAULT','16');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DESC','17');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DISTINCT','18');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DOUBLE','19');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EACH','20');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ENCLOSED','21');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXIT','22');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FETCH','23');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT8','24');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FOREIGN','25');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('GRANT','26');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HIGH_PRIORITY','27');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_SECOND','28');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IN','29');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INNER','30');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INSERT','31');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT2','32');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT8','33');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTO','34');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('JOIN','35');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KILL','36');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEFT','37');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LINEAR','38');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCALTIME','39');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONG','40');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOOP','41');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MATCH','42');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMTEXT','43');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MINUTE_SECOND','44');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NATURAL','45');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NULL','46');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTIMIZE','47');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OR','48');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUTER','49');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PRIMARY','50');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RANGE','51');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READ_WRITE','52');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REGEXP','53');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REPEAT','54');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RESTRICT','55');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RIGHT','56');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SCHEMAS','57');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SENSITIVE','58');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SHOW','59');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SPECIFIC','60');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLSTATE','61');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_CALC_FOUND_ROWS','62');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('STARTING','63');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TERMINATED','64');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYINT','65');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRAILING','66');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNDO','67');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNLOCK','68');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USAGE','69');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_DATE','70');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VALUES','71');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARCHARACTER','72');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHERE','73');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WRITE','74');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ZEROFILL','75');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ALL','76');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('AND','77');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ASENSITIVE','78');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BIGINT','79');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BOTH','80');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CASCADE','81');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHAR','82');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('COLLATE','83');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONSTRAINT','84');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CREATE','85');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_TIME','86');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURSOR','87');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_HOUR','88');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_SECOND','89');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DECLARE','90');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DELETE','91');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DETERMINISTIC','92');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DIV','93');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DUAL','94');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ELSEIF','95');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXISTS','96');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FALSE','97');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT4','98');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FORCE','99');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FULLTEXT','100');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HAVING','101');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_MINUTE','102');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IGNORE','103');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INFILE','104');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INSENSITIVE','105');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT1','106');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT4','107');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTERVAL','108');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ITERATE','109');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KEYS','110');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEAVE','111');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LIMIT','112');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOAD','113');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCK','114');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONGTEXT','115');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MASTER_SSL_VERIFY_SERVER_CERT','116');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMINT','117');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MINUTE_MICROSECOND','118');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MODIFIES','119');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NO_WRITE_TO_BINLOG','120');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ON','121');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTIONALLY','122');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUT','123');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PRECISION','124');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PURGE','125');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READS','126');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REFERENCES','127');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RENAME','128');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REQUIRE','129');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REVOKE','130');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SCHEMA','131');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SELECT','132');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SET','133');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SPATIAL','134');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLEXCEPTION','135');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_BIG_RESULT','136');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SSL','137');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TABLE','138');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYBLOB','139');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TO','140');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRUE','141');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNIQUE','142');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UPDATE','143');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USING','144');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_TIMESTAMP','145');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARCHAR','146');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHEN','147');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WITH','148');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('YEAR_MONTH','149');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ADD','150');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ANALYZE','151');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ASC','152');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BETWEEN','153');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BLOB','154');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CALL','155');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHANGE','156');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHECK','157');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONDITION','158');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONVERT','159');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_DATE','160');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_USER','161');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DATABASES','162');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_MINUTE','163');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DECIMAL','164');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DELAYED','165');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DESCRIBE','166');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DISTINCTROW','167');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DROP','168');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ELSE','169');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ESCAPED','170');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXPLAIN','171');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT','172');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FOR','173');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FROM','174');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('GROUP','175');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_MICROSECOND','176');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IF','177');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INDEX','178');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INOUT','179');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT','180');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT3','181');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTEGER','182');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IS','183');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KEY','184');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEADING','185');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LIKE','186');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LINES','187');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCALTIMESTAMP','188');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONGBLOB','189');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOW_PRIORITY','190');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMBLOB','191');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MIDDLEINT','192');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MOD','193');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NOT','194');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NUMERIC','195');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTION','196');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ORDER','197');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUTFILE','198');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PROCEDURE','199');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READ','200');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REAL','201');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RELEASE','202');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REPLACE','203');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RETURN','204');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RLIKE','205');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SECOND_MICROSECOND','206');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SEPARATOR','207');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SMALLINT','208');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL','209');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLWARNING','210');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_SMALL_RESULT','211');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('STRAIGHT_JOIN','212');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('THEN','213');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYTEXT','214');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRIGGER','215');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNION','216');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNSIGNED','217');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USE','218');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_TIME','219');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARBINARY','220');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARYING','221');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHILE','222');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('XOR','223');

CREATE TABLE `users` (
  `pass` text NOT NULL,
  `user` varchar(10) NOT NULL,
  `right` int(1) NOT NULL DEFAULT '0',
  `sid` varchar(200) DEFAULT NULL,
  `ip` varchar(50) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');

